@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "16.0.1";
+        "17.0.13";
 
     private static final String java_version_date =
-        "2021-04-20";
+        "2024-10-15";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,49 +49,49 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "16.0.1+9-24";
+        "17.0.13+11";
 
     private static final String VERSION_NUMBER =
-        "16.0.1";
+        "17.0.13";
 
     private static final String VERSION_SPECIFICATION =
-        "16";
+        "17";
 
     private static final String VERSION_BUILD =
-        "9";
+        "11";
 
     private static final String VERSION_PRE =
         "";
 
     private static final String VERSION_OPT =
-        "24";
+        "";
 
     private static final boolean isLTS =
-        "24".startsWith("LTS");
+        "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "60.0";
+        "61.0";
 
     private static final String VENDOR =
-        "Oracle Corporation";
+        "Eclipse Adoptium";
 
     private static final String VENDOR_URL =
-        "https://java.oracle.com/";
+        "https://adoptium.net/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "";
+        "Temurin-17.0.13+11";
 
     private static String VENDOR_URL_BUG =
-        "https://bugreport.java.com/bugreport/";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     // This field is read by HotSpot
     @SuppressWarnings("unused")
     private static String VENDOR_URL_VM_BUG =
-        "https://bugreport.java.com/bugreport/crash.jsp";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     /**
      * Initialize system properties using build provided values.
@@ -109,6 +109,7 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
+        props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
